# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Attributes;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "1.11";

our @GEOOPTIONS = 
  (
   { name => 'match',
     help => 'Only lists attributes names containing this value',
     title => 'Optional string to match:',
   },
   { name => 'orderby',
     help => 'Can be set to order by "attributename" (default) or "attributeid"',
     title => 'Order By:',
     values => [qw(attributename attributeid)],
     default => 'attributename'
   }
  );

sub display {
    my ($self, $set, $dbh) = @_;

    GEODEBUG(3, "Displaying the saved database \"attributes\"\n");

# need to check CPU intensivity after a fully loaded:

#     my $sth = $dbh->prepare('select attributes.id as attrid,
#                                     attributes.attributename as attrname,
#                                     count(ident) as idcount,
#                                     from attributenames
#                           left join attributes
#                                  on attributes.attributeid =
#                                     attributes.attributeid
#                               group by attributes.name');

    my $sth = $dbh->prepare('select attributeid as attrid,
                                    attributename as attrname
                                    from attributenames
                           order by ' . $self->{'options'}{'orderby'});

    $sth->execute();
    my $rows = $sth->fetchall_arrayref;
    my $out;
    $out .= sprintf("%6s  %-40s\n",  'Id', 'Attribute Name' );
    $out .= sprintf("%-6s  %-40s\n",  '-' x 6, '-' x 40);
    my $match = $self->{'options'}{'match'};
    foreach my $row (@$rows) {
	if (!$match || $row->[1] =~ /$match/) {
	    $out .= sprintf("%6d  %-40s\n",  $row->[0], $row->[1]);
	}
    }
    return $out;
}

1;

=head1 NAME

Attributes - Display a list of the known groundspeak/geocaching

=head1 DESCRIPTION

START HELP

  Example:
  geoqo -d attributes
    Id  Attribute Name
------  ----------------------------------------
     1  Dogs
     3  Climbing gear
     4  Boat
     5  Scuba gear
 [...]

Shows the list of known groundspeak/geocaching attributes.  This is
useful for knowing which attributes you can search with using the
'attribute' search plugin.

END HELP

=cut
