# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Firefox;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "1.11";

our @GEOOPTIONS = 
  (
   { name => 'type' }
  );

sub display {
     my ($self, $set, $dbh) = @_;

     GEODEBUG(3, "Firefoxing a set\n");
     $set->load({nologs => !($self->{'options'}{'logs'})});
     # generally should be only one?
     my $output;

     if ($self->{'options'}{'type'} eq 'log') {
	 $set->foreach(
	     sub { 
		 my $cache = shift;
		 if (exists($cache->{'attributes'}{'trkptstamp'})) {
		     $output .= "Visited at:     $cache->{'attributes'}{'trkpttime'}\n";
		     $output .= "Was there for:  $cache->{'attributes'}{'trkptnearby'}\n";
		     $output .= "\n";
		 }

		 if (exists($cache->{'attributes'}{'logdata'})) {
		     $output .= $cache->{'attributes'}{'logdata'};
		 }
	     }
		      );
     } else {
	 $set->foreach(
         sub {
	     my $cache = shift;
	     my $doneone = 0;

	     #
	     #tags
	     #
	     if (exists($cache->{'tags'})) {
		 $output .= "<tr><td class=\"containerRow\"><b>Tags:</b></td></tr>\n";
		 $output .= "<tr><td class=\"containerRow\"><table width=\"100%\"><tbody>\n";
		 $output .= "<tr><th>Name</th><th>Yours</th><th>Others</th></tr>\n";
		 foreach my $tag (sort keys(%{$cache->{'tags'}})) {
		     $output .= "<tr><td>$tag</td><td>" .
		       ($cache->{'tags'}{$tag}{'ismine'} ? "X" : "&nbsp;") .
			 "</td><td>$cache->{'tags'}{$tag}{'count'}</td></tr>\n";
		 }
		 $output .= "</tbody></table></tr></td>\n";
		 $doneone = 1;
	     }

	     #
	     #ratings
	     #
	     if (exists($cache->{'ratings'})) {
		 $output .= "<br />" if ($doneone);
		 $output .= "<tr><td class=\"containerRow\"><b>Ratings:</b></td></tr>\n";
		 $output .= "<tr><td class=\"containerRow\"><table width=\"100%\"><tbody>\n";
		 $output .= "<tr><th>Name</th><th>Yours</th><th>Average <br /> (Votes)</th></tr>\n";
		 foreach my $rating (sort keys(%{$cache->{'ratings'}})) {
		     $output .= "<tr><td>$rating</td><td>$cache->{'ratings'}{$rating}{'value'}</td><td>$cache->{'ratings'}{$rating}{'othersrating'} ($cache->{'ratings'}{$rating}{'count'})</td></tr>\n";
		 }
		 $output .= "</tbody></table></tr></td>\n";
		 $doneone = 1;
	     }


	     #
	     #attributes
	     #
	     if (exists($cache->{'attributes'})) {
		 $output .= "<br />" if ($doneone);
		 $output .= "<tr><td class=\"containerRow\"><b>Attributes:</b></td></tr>\n";
		 $output .= "<tr><td class=\"containerRow\"><table width=\"100%\"><tbody>\n";
		 $output .= "<tr><th>Name</th><th>Value</th></tr>\n";
		 foreach my $attribute (sort keys(%{$cache->{'attributes'}})) {
		     $output .= "<tr><td>$attribute</td><td>$cache->{'attributes'}{$attribute}</td></tr>\n";
		 }
		 $output .= "</tbody></table></tr></td>\n";
		 $doneone = 1;
	     }
	 }
     );
     }

     # return a bogus string for the firefox plugin to realize we hit the end
     return $output . "xxxgeoqoxxx";
}


1;

=head1 NAME

Firefox - Output for the firefox extension

=head1 DESCRIPTION

START HELP

You shouldn't use this plugin directly; use the firefox extension.

END HELP

=cut

