# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Gui::List::Plugin::Solve;

use strict;

use GeoDB::Display::Gui::List::Plugin;
use QWizard;
use QWizard::API;
use GeoDB::Set;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display::Gui::List::Plugin);

our $VERSION = "1.11";

sub get_def_coords {
    my ($cache) = shift;
    my ($n, $w) = sprint_coords($cache->{'data'}{'lat'},
				$cache->{'data'}{'lon'});
    $n =~ s/\.[0-9]{3}/\./;
    $w =~ s/\.[0-9]{3}/\./;
    $n  = $cache->{'attributes'}{'puzn'} || $n;
    $w  = $cache->{'attributes'}{'puzw'} || $w;
    return ($n, $w);
}

sub get_extra_rows {
    my ($self, $cache, $num) = @_;
    $cache->load_parts({logs => 1, tags => 1, attributes => 1});
    my ($n, $w) = get_def_coords($cache);
    my $row = 
      [{ type => 'checkbox',
	 name => $cache->{'data'}{'ident'} . ':solved',
	 button_label => "solved",
	 values => [1,0],
	 default => ((exists($cache->{'tags'}{'solved'}) &&
		      $cache->{'tags'}{'solved'}{'ismine'}) ? 
		     1 : 0)
       },
       { type => 'checkbox',
	 name => $cache->{'data'}{'ident'} . ':infield',
	 button_label => "infield",
	 values => [1,0],
	 default => ((exists($cache->{'tags'}{'infield'}) &&
		      $cache->{'tags'}{'infield'}{'ismine'}) ? 
		     1 : 0)
       },
       "Or:",
       qw_text($cache->{'data'}{'ident'} . ':puzn', '', default => $n),
       qw_text($cache->{'data'}{'ident'} . ':puzw', '', default => $w),
      ];
    return $row;
}

sub post_answers {
    my ($self, $qw, $set, $listobj) = @_;

    $set->foreach(sub {
			  my ($cache) = @_;
 			  if (qwparam($cache->{'data'}{'ident'} . ":infield")) {
			      $cache->set_tag('infield');
			  } else {
			      $cache->remove_tag('infield');
			  }

 			  if (qwparam($cache->{'data'}{'ident'} . ":solved")) {
			      $cache->set_tag('solved');
			  } else {
			      $cache->remove_tag('solved');
			  }

			  my ($n, $w) = get_def_coords($cache);
			  my $saveit = 0;
			  if (qwparam($cache->{'data'}{'ident'} . ":puzn") &&
			      qwparam($cache->{'data'}{'ident'} . ":puzn") ne
			      $n) {
			      $cache->{'attributes'}{'puzn'} =
				qwparam($cache->{'data'}{'ident'} . ":puzn");
			      $saveit = 1;
			  }
			  if (qwparam($cache->{'data'}{'ident'} . ":puzw") &&
			      qwparam($cache->{'data'}{'ident'} . ":puzw") ne
			      $w) {
			      $cache->{'attributes'}{'puzw'} =
				qwparam($cache->{'data'}{'ident'} . ":puzw");
			      $saveit = 1;
			  }
			  if ($saveit) {
			      $cache->save_attributes();
			  }
		      });
    return 0;
}

1;
