# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Gui::Show;

use strict;
use GeoDB::Display;
use GeoDB::Utils;
use QWizard;

our @ISA = qw(GeoDB::Display);

our $VERSION = "1.11";

my @extracols = qw(found puzn puzw infield distance);

sub display {
     my ($self, $set, $dbh) = @_;

     GEODEBUG(3, "Showing a set\n");
     $set->load_parts({ logs => $self->{'options'}{'logs'},
			attributes => 1,
			gcattributes => 1,
			tags => 1});
     my $qw = $self->get_qwizard();
     my $keeprunning = 1;
     $qw->merge_primaries({'guidisplay' =>
			   {
			    title => "Displaying Caches",
			    questions =>
			    [
			     { type => 'menu',
			       name => 'cachenum',
			       text => 'Waypoint:',
			       refresh_on_change => 1,
			       labels =>
			       [sub {
				    my $set = $_[$#$_];
				    my @labels;
				    my $num = $set->num();
				    for (my $i = 0; $i < $num; $i++) {
					my $cache = $set->get($i);
					push @labels, $i,
					  "$cache->{'data'}{'ident'} $cache->{'data'}{'desc'}";
				    }
				    return \@labels;
				}, $set]
			     },
			     {
			       type => 'table',
			       values =>
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    my $table;
				    my ($cols, $map) =
				      $cache->get_registered_cols_and_map();
				    foreach my $it (@$cols, @extracols) {
					next if ($it =~ /description/);
					push @$table,
					  [$it, $cache->{'data'}{$it}]
					    if ($cache->{'data'}{$it});
				    }
				    return [$table];
				}, $set]
			      },
			     {
			      type => 'table',
			      text => 'Attributes:',
			      doif => 
			      # why doesn't this work?  qwizard bug?
			      # no matter what's returned, always not displayed
			      sub {
				  my $set = $set;
				  my $cache = $set->get(qwparam('cachenum') || 0);
				  my @keys = keys(%{$cache->{'attributes'}});
				  return ($#keys > -1);
			      },
			      values =>
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    my $table;
				    foreach my $it (keys(%{$cache->{'attributes'}})) {
					push @$table,
					  [$it, $cache->{'attributes'}{$it}]
					    if ($cache->{'attributes'}{$it});
				    }
				    return [$table];
				}, $set]
			      },
			     {
			      type => 'table',
			      text => 'Your Tags:',
			      doif =>
			      # why doesn't this work?  qwizard bug?
			      # no matter what's returned, always not displayed
			      sub {
				  my $set = $set;
				  my $cache = $set->get(qwparam('cachenum') || 0);
				  my @keys = keys(%{$cache->{'tags'}});
				  return ($#keys > -1);
			      },
			      values =>
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    my $table = [];
				    my $row = [];
				    foreach my $it (keys(%{$cache->{'tags'}})) {
					push @$row, $it
					  if ($cache->{'tags'}{$it}{'ismine'});
					if ($#$row >= 5) {
					    push @$table, $row;
					    $row = [];
					}
				    }
				    push @$table, $row if ($#$row > -1);
				    return [$table];
				}, $set]
			      },
			     {
			      type => 'table',
			      text => 'Other\'s Tags:',
			      doif =>
			      # why doesn't this work?  qwizard bug?
			      # no matter what's returned, always not displayed
			      sub {
				  my $set = $set;
				  my $cache = $set->get(qwparam('cachenum') || 0);
				  my @keys = keys(%{$cache->{'tags'}});
				  return ($#keys > -1);
			      },
			      values =>
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    my $table = [];
				    my $row = [];
				    foreach my $it (keys(%{$cache->{'tags'}})) {
					push @$row, "${it}($cache->{'tags'}{$it}{'count'})"
					  if ($cache->{'tags'}{$it}{'count'} > 0);
					if ($#$row >= 5) {
					    push @$table, $row;
					    $row = [];
					}
				    }
				    push @$table, $row if ($#$row > -1);
				    return [$table];
				}, $set]
			     },
			     {
			      type => 'table',
			      text => 'GC Attributes:',
			      doif =>
			      # why doesn't this work?  qwizard bug?
			      # no matter what's returned, always not displayed
			      sub {
				  my $set = $set;
				  my $cache = $set->get(qwparam('cachenum') || 0);
				  my @keys = keys(%{$cache->{'gcattributes'}});
				  return ($#keys > -1);
			      },
			      values =>
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    my $table = [];
				    my $row = [];
				    foreach my $it (keys(%{$cache->{'gcattributes'}})) {
					my $not = "";
					$not = "NOT " if (!$cache->{'gcattributes'}{$it}{'inc'});
					push @$row, "$not$cache->{'gcattributes'}{$it}{'name'}";
					if ($#$row >= 3) {
					    push @$table, $row;
					    $row = [];
					}
				    }
				    push @$table, $row if ($#$row > -1);
				    return [$table];
				}, $set]
			     },
			     {
			      type => 'paragraph',
			      preformatted => 1,
			      text => 'Short:',
			      values => 
			      [sub {
				   my $set = $_[$#_];
				   my $cache = $set->get(qwparam('cachenum') || 0);
				   return format_output($cache->{'data'}{'groundspeak_short_description'},
							$cache->{'data'}{'groundspeak_short_description_html'});
			       }, $set],
			     },
			     {
			      type => 'paragraph',
			      preformatted => 1,
			      text => 'Long:',
			      values => 
			      [sub {
				   my $set = $_[$#_];
				   my $cache = $set->get(qwparam('cachenum') || 0);
				   return format_output($cache->{'data'}{'groundspeak_long_description'},
							$cache->{'data'}{'groundspeak_long_description_html'});
			       }, $set],
			     },
			     { type => 'button',
			       name => 'setattr',
			       default => 1,
			       values => 'Set Attribute',
			     },
			    ],

			   post_answers => [sub {
			       if (qwparam('setattr')) {
				   $_[0]->add_todos('setattr');
			       } else {
				   $keeprunning = 0;
			       }
			   }]},
			   'setattr' =>
			   { title => 'Set an attribute',
			     questions => 
			     [{
			       type => 'label',
			       text => 'Identifier:',
			       values => 
			       [sub {
				    my $set = $_[$#_];
				    my $cache = $set->get(qwparam('cachenum') || 0);
				    return $cache->{'data'}{'ident'};
				}, $set]
			      },
			      { type => 'table',
				headers => [['Attribute Name','Attribute Value']],
				text => 'Set:',
				values => sub {
				    my $table = [];
				    for (my $i = 0; $i < 5; $i++) {
					push @$table,
					  [
					   {type => 'text',
					    name => 'attrname' . $i,
					    text => 'Attribute Name:'
					   },
					   {type => 'text',
					    name => 'attrval' . $i,
					    text => 'Attribute Value:'
					   },
					  ];
				    }
				    return [$table];
				},
			      },
			     ],
			     post_answers => 
			     [[sub {
				   my $set = $_[$#_];
				   my $cache = $set->get(qwparam('cachenum') || 0);
				   for (my $i = 0; $i < 5; $i++) {
				       $cache->{'attributes'}{qwparam('attrname' . $i)} = qwparam('attrval' . $i)
					 if (qwparam('attrname' . $i));
				   }
				   $cache->save_attributes();
			       }, $set]],
			    }
			  });
     while ($keeprunning) {
	 $qw->magic('guidisplay');
     }
}


1;

=head1 NAME

gui/show - Display a GUI showing details of a search set

=head1 DESCRIPTION

START HELP

  Example:
  geoqo -s cache:urlname=funny -d gui/show

The gui/show module displays a GUI in a graphical window that lets you
examine the caches within a cache set.

This is only very preliminary work and is subject to greater expansion
in the future.

END HELP

=cut
