# Copyright (C) 2008 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Map;

use strict;
use GeoDB::Display;
use GeoDB::Utils;
use GD;
use GeoDB::Export::Map;

my $have_qw = eval "require QWizard";

our @ISA = qw(GeoDB::Display);

our $VERSION = "1.11";

our @GEOOPTIONS = @GeoDB::Export::Map::GEOOPTIONS;

sub display {
    my ($self, $set) = @_;

    GEOERR("can't display graphs: QWizard perl module not installed")
      if (!$have_qw);

    my $mapexport = new GeoDB::Export::Map(options => $self->{'options'});

    my $qw = 
      new QWizard(primaries => 
		  {'disp' =>
		   {title => 'Map Display',
		    questions => [{
				   name => 'img',
				   type => 'image',
				   imgdata => sub {
				       my $im = $mapexport->make_export($set);
				       return [$im->png()];
				   }
				  }]
		   }}
		 );
    $qw->magic('disp');
    $qw->finished();
}

1;

=head1 NAME

Map - Map the contents of a set of waypoints

=head1 DESCRIPTION

START HELP

  Example 1:
  geoqo -s 'set:import:My Pocket Query' -d map

The I<Map> display plugin displays a map of a set of waypoints with
little red dots for each waypoint.

This plugin requires internet access since the map tiles are pulled
from the http://www.openstreetmap.org/ project (which I highly
recommend you contribute to; it's easy and fun to edit/fix the maps!).

(Eventually it should be possible to display with symbols, colors, etc
as well as display the density overlays like the KML export plugin
does)

END HELP

=cut

