# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Display::Sets;

use strict;
use GeoDB::Display;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Display);

our $VERSION = "1.11";

our @GEOOPTIONS = 
  (
   { name => 'match',
     help => 'Only lists set names containing this value',
     title => 'Optional string to match:',
   },
   { name => 'orderby',
     help => 'Can be set to order by "modified" (default) or "setname" or "count"',
     title => 'Order By:',
     values => [qw(modified setname count)],
     default => 'modified'
   }
  );

sub display {
    my ($self, $set, $dbh) = @_;

    GEODEBUG(3, "Displaying the saved database \"Sets\"\n");

    my $sth = $dbh->prepare('select sets.name as setname, count(ident) as count,
                                    modified from sets
                          left join setinfo 
                                 on sets.name = setinfo.name
                              group by sets.name
                              order by ' .
			    $self->{'options'}{'orderby'});
    $sth->execute();
    my $rows = $sth->fetchall_arrayref;
    my $out;
    $out .= sprintf("%6s %10s %s\n",  'Count', 'Modified', 'Set Name' );
    $out .= sprintf("%6s %10s %s\n",  '-' x 5, '-' x 10, '-' x 40 );
    my $match = $self->{'options'}{'match'};
    foreach my $row (@$rows) {
	if (!$match || $row->[0] =~ /$match/) {
	    $out .= sprintf("%6d %10s %-50s\n",  $row->[1], $row->[2],
			    $row->[0]);
	}
    }
    return $out;
}

1;

=head1 NAME

Sets - Display a list of the saved sets

=head1 DESCRIPTION

START HELP

  Example:
  geoqo -d sets
 Count Set Name
 ----- ----------------------------------------
   450 import:Bethel Island
   500 import:Concord
   500 import:Copy of SanFrancisco
 [...]

Shows the list of existing sets remembered by the geoqo system, and
the number of caches in each one.  See the geoqo documentation on
"sets" for further details.

END HELP

=cut
