# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Export::Html;

use strict;
use GeoDB::Export;
use GeoDB::Utils;

our $VERSION = "1.11";

our @ISA = qw(GeoDB::Export);

our @GEOOPTIONS =
  ({ name => 'subdir',
     title => 'Subdirectory for cache files:',
     help => 'Puts created HTML files in this sub directory name.',
     default => 'caches'
   },
   { name => 'title',
     title => 'Title for the top of the page:',
     help => 'The title to put at the top of the page',
     default => 'GeoDB HTML Export'
   },
  );

sub _x {
    return GeoDB::Export::_add_basic_entity(@_);
}

sub export_it {
    my ($self, $file, $set) = @_;

    GEODEBUG(1,"writing file: $file\n");
    open(IDX, ">$file");

    print IDX "<html>
  <head>
    <title>" . _x($self->{'options'}{'title'}) . "</title>
 <style type=\"text/css\">
   <!--
/* ********************************************************************** */
/* TABLES */
table { 
  border-color: #aaf;
  border-style: solid;
  border-width: 2px;
  margin-left: 50px;
}

th { 
  background-color: #ccf;
}

table.coverlist td, table.coverlist th { 
  border-color: #fff #99f #fff #99f;
  border-style: solid;
  border-width: 1px;
  padding-left: 4px;
  padding-right: 4px;
}

h1{background:#cceecc}
-->
</style>
  </head>
  <body>
    <h1>" . _x($self->{'options'}{'title'}) . "</h1>
    <table>
      <tr><th>Identifier</th><th>Description</th></tr>
";

    $set->load_parts({logs => $self->{'options'}{'logs'}});
    $self->{'options'}{'subdir'} ||= 'caches';
    mkdir($self->{'options'}{'subdir'});
    $set->foreach(sub {
		      my $c=$_[0]{'data'};
		      print IDX "<tr><td><a href=\"$self->{'options'}{'subdir'}/$c->{ident}.html\">$c->{ident}</a></td><td>" . _x($c->{'desc'}) . "</td></tr>\n";
		      open(O,">" . $self->{'options'}{'subdir'} . "/" . $c->{'ident'} . ".html");
		      print O "
<html>
<head>
 <style type=\"text/css\">
   <!--
/* ********************************************************************** */
/* TABLES */
table { 
  border-color: #aaf;
  border-style: solid;
  border-width: 2px;
  margin-left: 50px;
}

h2 {
  background-color: #cfc;
}

th { 
  background-color: #ccf;
}

table.coverlist td, table.coverlist th { 
  border-color: #fff #99f #fff #99f;
  border-style: solid;
  border-width: 1px;
  padding-left: 4px;
  padding-right: 4px;
}

h3{background:#cceecc}
-->
</style>
<title>" . _x($c->{desc}) . "</title>
</head>
<body>
<h2>$c->{'ident'}</h2>
<table>
<tr><th>Name:</th><td>" . _x($c->{desc}) . "</td></tr>
<tr><th>Diff/Terr:</th><td>$c->{groundspeak_difficulty} / $c->{groundspeak_terrain}</td></tr>\n" .
(($c->{distance}) ? "<tr><th>Distance:</th><td>$c->{distance}</td></tr>\n" : "") .
"";
		      foreach my $i (qw(lat lon subtype groundspeak_short_description groundspeak_long_description)) {
			  my $name = $i;
			  $name =~ s/groundspeak_//;
			  $name =~ s/_/ /g;
			  print O "<tr><th>$name:</th><td>" . $c->{$i} . "</td></tr>\n"
			    if (exists($c->{$i}));
		      }
				     print O "
</table>
";
		      if (0 && !$_[1] && exists($_[0]->{'logs'})) {
			  print O "      <groundspeak:logs>\n";
			  foreach my $logid (sort { $a <=> $b } keys(%{$_[0]->{'logs'}})) {
			      my $log = $_[0]->{'logs'}{$logid};
			      print O "        <groundspeak:log id=\"" . _x($log->{'id'}) . "\">
            <groundspeak:date>" . _x($log->{'date'}) . "</groundspeak:date>
            <groundspeak:type>" . _x($log->{'type'}) . "</groundspeak:type>
            <groundspeak:finder id=\"" . _x($log->{'finder_id'}) . "\">" . _x($log->{'finder'}) . "</groundspeak:finder>
            <groundspeak:text encoded=\"" . _x($log->{'text_encoded'}) . "\">" . _x($log->{'text'}) . "</groundspeak:text>
        </groundspeak:log>
";
			  }
			  print O "      </groundspeak:logs>\n";
		      }
		      print O "</body></html>";
		      close(O);
		  }, $self->{'options'}{'nologs'});
    print IDX "</body></html>\n";
    close(IDX);
    close(O);
}

1;

=head1 NAME

Html - export html files

=head1 DESCRIPTION

START HELP

  > geoqo -s 'cache:name=cool cache' -e myfile.html

  Prints a set of caches to a series of web pages.  Each cache will
  get it's own file and a top level index file will be created that
  links to each cache page.

  Very useful for outputting geocaches to plucker.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
