# Copyright (C) 2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::Base64;

require GeoDB::Import::Files;

maybe_load('MIME::Base64', "You need the MIME::Base64 perl module to support loading of base64 encoded items\n");


use GeoDB;
use GeoDB::Utils;
use GeoDB::Set;
use strict;

our $VERSION = "1.11";

our @ISA = qw(GeoDB::Import::Files);

our @GEOOPTIONS = 
({ name => 'skiptobase64',
   text => 'Skip all until a base64 MIME header',
   type => 'checkbox',
   advanced => 1,
 },
 { name => 'isgcemail',
   text => 'process completely as if a email PQ from groundspeak',
   type => 'checkbox',
   advanced => 1,
 },
 { name => 'setname',
   text => 'Set Name for new Point:',
   default => 'created',
 },
);

@GEOOPTIONS = @GeoDB::Import::Files::GEOOPTIONS;

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;
    GEODEBUG(1,"reading base64 from file: $file\n");

    my $tmpdir = $self->{'options'}{'tmpdir'};
    mkdir($tmpdir) if (! -d $tmpdir);

    # read in the base64 content from the input
    my $base64str = "";
    my $str;
    open(I,$file);

    $self->{'options'}{'skiptobase64'} = 1 if ($self->{'options'}{'isgcemail'});

    if ($self->{'options'}{'skiptobase64'}) {
	while (<I>) {
	    if ($self->{'options'}{'isgcemail'} && 
		/Subject:.*Query: *(.*)/) {
		$self->{'options'}{'setname'} = "import:" . $1;
	    }
	    last if (/Content-Transfer-Encoding: base64/);
	}
	$str = <I>;
	$str = "" if ($str =~/^\s*$/);

	# XXX: rewind if not found?
	GEODEBUG(5, "skipped until base64 header\n");
    }


    while (read(I,$str,4096)) {
	$base64str .= $str;
    }
    close(I);

    GEODEBUG(4, "decoding base64\n");
    my $decodedstr = MIME::Base64::decode_base64($base64str);

    # now save it to a file
    # XXX: assumes zip
    my $filename = "base64tmp.zip";

    # XXX: check to see if we can handle it (this returns true if so)
    # if ($self->check_filename($filename))

    GEODEBUG(5,"outputting to: $tmpdir . / . $filename\n");
    open(O,">$tmpdir/$filename");
    print O $decodedstr;
    close(O);

    # create the set to return
    my $set = new GeoDB::Set();
    $set->set_name(($self->{options}{setname}) ? $self->{options}{setname} :
                    "import:" . $file); 

    # then process the file:
    $self->handle_file($dbh, $set, $tmpdir . "/" . $filename);
    unlink($tmpdir . "/" . $filename);

    GEODEBUG(5,$set->num() . " waypoints in set we return.\n");
    return $set;
}

1;

=head1 NAME

Base64 - import Base64 encoded files

=head1 DESCRIPTION

START HELP

  > cat message | geoqo -i base64:-

The I<base64> importer allows you to send mail messages with encoded
pocket queries directly to geoqo for decoding, unzipping, extracting
and importing.

Note: using this importer requires you to have B<MIME::Base64>
installed on your system.  Most modern perl packages contain this
out of the box.

END HELP

=head3 Options:

=over

=item tmpdir=DIR

The zip importer works by copying the zip file to a tmpdir and then
unzipping it there.  This is normally set to I<$HOME/.geoqo/tmpdir>.
This option lets you override that default.

=back

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
