# Copyright (C) 2008 Wes Hardaker
# License: GNU GPLv2.  See the COPYING file for details.

#
# this is a base class for other file import types like GeoDB::Import::Zip
#
package GeoDB::Import::Files;

require GeoDB::Import;

use GeoDB;
use GeoDB::Utils;
use GeoDB::Set;
use strict;

our $VERSION = "1.11";

our @ISA = qw(GeoDB::Import);

our @GEOOPTIONS = 
(
 { name => 'setname',
   advanced => 1,
   text => 'Overide the default set name:',
   help => 'Uses setname as the name of geoqo SET to create based on the data. Normally this is extracted from the I<name> field within the gpx file itself and prepended with "import:".  IE, if you had a pocket query named "my search" then, when you imported the gpx file into geoqo, you\'d get a new set named "import:my search".'},
 { name => 'tmpdir',
   help => 'The zip importer works by copying the zip file to a tmpdir and then unzipping it there.  This is normally set to I<$HOME/.geoqo/tmpdir>. This option lets you override that default.',
   nogui => 1,
   default => $ENV{'HOME'} . "/.geoqo/temp",
 },
);

sub check_filename {
    my ($self, $zipf) = @_;
    my ($type, $file) = GeoDB::get_type_and_file($zipf);
    my $engine = $self->new_engine("$type:nogui=1", 'Import');
    if ($engine && ref($engine) =~ /GeoDB::Import/) {
	return $engine;
    }
    return 0;
}

sub handle_file {
    my ($self, $dbh, $set, $file) = @_;
    GEODEBUG(5,"Considering $file\n");
    my $type;
    ($type, $file) = GeoDB::get_type_and_file($file);
    return if (!$type);
    my $engine = $self->new_engine("$type:nogui=1", 'Import');
    if ($engine && ref($engine) =~ /GeoDB::Import/) {
	GEODEBUG(5,"... $type - Importing\n");

	# geocaching.com smart setname hack (see below)
	$engine->{'options'}{'setname'} = $self->{'wptsetnames'}{$file}
	  if (exists($self->{'wptsetnames'}{$file}));
	
	# pass in our set name
	$engine->{'options'}{'setname'} = $self->{'options'}{'setname'}
	  if ($self->{'options'}{'setname'});

	my $tmpset = $engine->import_it($file, $dbh);

	# geocaching.com smart setname hack:
	# setname was specified.  remember a variation of this
	# file name to best support geocaching.com extra waypoint
	# files which end in -wpts.
	if ($tmpset->get_name() =~ /import:/) {
	    $file =~ s/\.gpx/-wpts.gpx/;
	    $self->{'wptsetnames'}{$file} = $tmpset->get_name() . ":waypoints";
	}

        GEODEBUG(5,$tmpset->num() . " waypoints loaded.\n");
	$set->merge($tmpset);
        GEODEBUG(5,$set->num() . " waypoints in merged set.\n");
    } else {
	GEODEBUG(5,"...Skipping\n");
    }
}

1;
