# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Import::Project;

require GeoDB::Import;
use GeoDB::Utils;
use GeoDB::Set;
use strict;
use QWizard;

our $VERSION = "1.11";

our @ISA = qw(GeoDB::Import);
our @GEOOPTIONS = 
({ name => 'ident',
   text => 'Identifier for new Waypoint:',
 },
 { name => 'type',
   text => 'Waypoint Type',
   type => 'menu',
   values => sub {
       return ['Waypoint', keys(%GeoDB::Waypoint::registered_types)];
   },
 },
 { name => 'from',
   text => 'From Waypoint:',
 },
 { name => 'distance',
   text => 'Distance:',
   helpdesc => '(eg format: 1mi, 2km, 3ft, 4yd)',
   default => 0,
 },
 { name => 'direction',
   text => 'Direction:',
   helpdesc => '(in degrees from True North)',
   default => 0,
 },
 { name => 'setname',
   text => 'Set Name for new Point:',
   default => 'created',
 },
 );

sub import_set {
    my ($self, $file, $dbh, %opts) = @_;

    my $from =
      new GeoDB::Waypoint({ data => 
			    {'ident' => $self->{'options'}{'from'}}
			  });
    $from->morph_to_specific(); # technically not needed...
    $from->load_parts();

    use Data::Dumper;;
    GEOERR("Failed to load waypoint: $self->{'options'}{'from'}")
      if (!$from);

    my $n = $from->{'data'}{'lat'};
    my $w = $from->{'data'}{'lon'};
    my $type = $self->{'options'}{'type'} || $from->{'data'}{'type'};

    my $set = new GeoDB::Set;
    my $name = $self->{'options'}{'setname'};

    my $waypoint =
      new GeoDB::Waypoint
	({
	  data =>
	  {
	   type => $type,
	   ident => $self->{'options'}{'ident'},
	   }
	 }
	);

    GEOERR("Failed to create waypoint: $self->{'options'}{'waypoint'}")
      if (!$waypoint);

    $waypoint->morph_to_specific();

    # set lat/lon based on projection

    my $distance = parse_distance($self->{'options'}{'distance'});
    GEODEBUG(3,"Projecting: " . $distance . " miles\n");
    $waypoint->{'data'}{'lat'} = $n; # XXX: insert math!
    $waypoint->{'data'}{'lon'} = $w; # XXX: insert math!

    $set->add($waypoint);
    $set->set_name($name) if($name);
    return $set;
}


1;

=head1 NAME

Project - Project a new waypoint from another one

=head1 DESCRIPTION

START HELP

XXXXX DO NOT USE THIS PLUGIN; IT IS NOT FINISHED XXXXX

  > geoqo -i project:ident=newwaypoint,from=oldwaypoint,distance=528,direction=45

The I<project> import plugin lets you project a new waypoint which is
a distance from an older one.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut
