# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Modify::Symbol;

use strict;
use GeoDB::Modify;

our @ISA = qw(GeoDB::Modify);
our $VERSION = "1.11";

sub modify {
    my ($self, $cache) = @_;

    $cache->load_parts({ attributes => 1});
    foreach my $arg (@{$self->{'optionsarray'}}) {
	my ($val, $sym) = ($arg->[1] =~ /([^=]*)=(.*)/);
	if ($cache->{'data'}{$arg->[0]} =~ /$val/ ||
	    $cache->{'attributes'}{$arg->[0]} =~ /$val/) {
	    $cache->{'data'}{'sym'} = $sym;
	    return;
	}
    }
}

1;

=head1 NAME

Symbol - Modifes the cache symbols based on other information about the cache

=head1 DESCRIPTION

START HELP

This plugin replaces symbol identifier (normally "Geocache" for
geocaches) with a new symbol based on your set criteria.

As an example, I (Yamar) use the following mem: file definition to
remap all my symbols into things that look (on my garmin) kind like
the cache container:

  symbol:
  subtype=Multi-cache=Fitness Center,
  subtype=Unknown Cache=Information,
  subtype=Webcam Cache=Shower,
  groundspeak_container=Micro=Cemetery,
  groundspeak_container=Small=Tunnel,
  groundspeak_container=Large=Geocache Found,
  subtype=Virtual Cache=Ultralight Area

Then I can run geoqo to remap stuff before exporting it to a .gpx file:

  > geoqo -s some_search_criteria -e 'mem:FILENAME+out.gpx'

That way all multi-caches get remapped to a 'Fitness Center' because
the 'Fitness Center' icon on my garmin looks like a little guy lifting
weights, and thus I know it's going to be a harder cache (or one I'll
likely have to walk more).  I like multi's a lot, but I do like to
know when I'm hitting them.  Similarily, a Cemetery icon on my etrex
is a small dot, a Tunnel is a bit larger, and a Geocache found icon is
very large so I use them to represent sizes.

If you want to use the symbol plugin, you should pick your own symbols
that seem right on your gps or other software system.  Each GPS's
symbols tend to be quite different (and the name chosen should be a
symbol your GPS or software actually matches).

=head3 Formatting

The format of the plugin is as follows:

  symbol:CACHEDATA=CACHEVALUE=SYMBOLNAME,CACHEDATA2=CACHEVALUE2=SYMBOLNAME2,

They are B<exact> matches only.  So the CACHEVALUE must exactly equal
the value found in the CACHEDATA field or it won't be replaced.  The
symbol plugin will stop after the first match so the first symbol in
the list that gets matched always wins.

END HELP

=cut
