# Copyright (C) 2007-2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Attribute;

=head1 NAME

Attribute - search groundpseak (geocaching) attributes

=head1 SYNOPSIS

geoqo -s attribute:myattr=myvalue -l

=head1 DESCRIPTION

START HELP

Attribute searches groundspeak (geocaching.com) attributes that were
loaded into the database when doing an import from a groundspeak .gpx
file.

  > geoqo -s attribute:Dogs -d count
  Search Result Count: 32

NOTE: this does NOT search the user-defined attributes and only
searches (geocaching.com) attributes.  For searching user attributes
you should use the attr: search plugin intstead.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

use GeoDB::Utils;
use GeoDB::Waypoint;

use strict;

our @ISA = qw(GeoDB::Search);

our $VERSION = "1.11";

sub search {
    my ($self, $criteria, $type) = @_;

    my $clause = "";
    my @values;

    GEODEBUG(3, "search groundspeak attributes: $criteria\n");
    my $clause = "";
    my @args = ();
    my $not = '';
    my @attributes = split(/,/,$criteria);
    foreach my $attribute (@attributes) {
	$clause .= ' or (attributeid = ? and attributeinc = ?)';
	my $posorneg = 1;
	$posorneg = "0" if ($attribute =~ s/^-//);
	push @args, $GeoDB::Waypoint::gcattributenames->{$attribute}, $posorneg;
    }
    $clause =~ s/ or /waypoints.ident $not in (select distinct ident from attributes where /;
    $clause .= ')';
    return ($clause, \@args);
}

1;
