# Copyright (C) 2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::File;

use strict;
use GeoDB::Search;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Search);

our $VERSION = "1.11";

our @GEOOPTIONS =
  (
   { name => 'file',
     help => 'A file to load and search for matching waypoints from'
   }
  );

sub search {
     my ($self, $criteria, $type) = @_;

     # load the file in question
     my ($type, $file) = GeoDB::get_type_and_file($self->{'options'}{'file'});
     $file = $type . ":bogus=1:" . $file;
     my $fileset = $self->get_master()->import_it({dontsave => 1}, $file);
     my $whereclause = "";
     my @idents;
     $fileset->foreach(sub {
			   $whereclause .= "or waypoints.ident = ? ";
			   # undo any diff/terrain modifications
			   $_[0]{'data'}{'ident'} =~ s/^\d\d(\w{4,5})/GC$1/;
			   push @idents, $_[0]{'data'}{'ident'};
		       });
     $whereclause =~ s/^or //;
     $whereclause = "( $whereclause )";

     GEODEBUG(3, "searching for idents from file: $whereclause\n");
     return $whereclause, \@idents;
}


1;

=head1 NAME

File - Searches for waypoints in the database that match those in a file

=head1 DESCRIPTION

START HELP

  > geoqo -s file:foo.gpx -d count
  Search/Set Count: 3

  > geoqo -s file:foo.loc -d count
  Search/Set Count: 3

The I<file> plugin loads a file into memory and then searches the
normal geoqo database for all the waypoints that match those found in
the file.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

