# Copyright (C) 2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Gps;

use strict;
use GeoDB::Search;
use GeoDB::Search::File;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Search);

our $VERSION = "1.11";

our @GEOOPTIONS =
  (
   { name => 'gpstype',
     values => [qw(garmin magelllan)],
     default => 'garmin',
     help => 'Type of GPS',
   },
   { name => 'gpsport',
     default => 'usb:',
     help => 'The port to use',
   }
  );

sub search {
     my ($self, $criteria, $type) = @_;

     my ($fh, $filelocation) = $self->get_temp_file(".loc");
     $fh->close();
     GEODEBUG(3,"Extracting GPS waypoints to $filelocation\n");
     GEODEBUG(3,"gpsbabel -i $self->{options}{gpstype} -f $self->{options}{gpsport} -o geo -F $filelocation\n");
     system("gpsbabel -i $self->{options}{gpstype} -f $self->{options}{gpsport} -o geo -F $filelocation");

     my $filesearch = $self->new_engine('file','Search');
     $filesearch->{'options'}{'file'} = $filelocation;
     my ($whereclause, $arguments) = $filesearch->search();
#     unlink($filelocation);
     return $whereclause, $arguments;
}


1;

=head1 NAME

Gps - Searches for waypoints in the database that match those in a gps

=head1 DESCRIPTION

START HELP

  > geoqo -s gps -d count
  Search/Set Count: 3

The I<gps> plugin talks to a gps and finds all the waypoints in the
geoqo database that are also in the GPS.  This is done by pulling out
all the waypoints from the GPS and then using the list to search the
database.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

