# Copyright (C) 2009 Hardaker
# License: GNU GPLv2.  See the COPYING file for details.
package GeoDB::Search::Returnhome;

use strict;
use GeoDB::Search;
use GeoDB::Search::Gps;
use GeoDB::Search::Track;
use GeoDB::Utils;

our @ISA = qw(GeoDB::Search);

our $VERSION = "1.11";

our @GEOOPTIONS =
  (
   { name => 'gpstype',
     text => 'GPS Type:',
     values => [qw(garmin magelllan)],
     default => 'garmin',
     help => 'Type of GPS',
   },
   { name => 'gpsport',
     text => 'GPS Port:',
     default => 'usb:',
     help => 'The port to use',
   }
  );

sub search {
     my ($self, $criteria, $type) = @_;

     my $gpssearch = $self->new_engine('Gps','Search');
     my ($whereclause, $arguments) = $gpssearch->search();

     my ($fh, $filelocation) = $self->get_temp_file(".gpx");
     $fh->close();
     GEODEBUG(3,"Extracting GPS track to $filelocation\n");
     system("gpsbabel -t -i $self->{options}{gpstype} -f $self->{options}{gpsport} -o gpx -F $filelocation");

     my $tracksearch = $self->new_engine('Track','Search');
     $tracksearch->{'options'}{'trackfile'} = $filelocation;
     my ($whereclause2, $arguments2) = $tracksearch->search();
     use QWizard;
     qwparam('trackfilename', $filelocation);
     $self->get_master()->{'options'}{'trackfilename'} = $filelocation;
     $self->{'options'}{'trackfilename'} = $filelocation;
     $GEODB::VARS{'trackfilename'} = $filelocation;
#     unlink($filelocation);

     $whereclause = "($whereclause and $whereclause2)";
     push @$arguments, @$arguments2;


     return $whereclause, $arguments;
}


1;

=head1 NAME

Returnhome - Searches for waypoints in the database that match those
             the gps got close to.

=head1 DESCRIPTION

START HELP

  > geoqo -s gps -d count
  Search/Set Count: 3

This plugin combines the functionality of a number of other ones
rolled into one.  In particular, it:

  1. pulls the existing waypoints from the GPS
  2. pulls the existing track from the GPS
  3. searches for the waypoints in the geoqo database that match the
     ones in the GPS using the GeoDB::Search::File plugin
  4. seaches the results of those for ones that the track came close
     using the GeoDB::Search::Track plugin.

END HELP

=head1 AUTHOR

Wes Hardaker (AKA Yamar) <hardaker ATAT users.sourceforge.net> 

=cut

